Function compress_to_buffer

fn compress_to_buffer(source: &[u8], destination: &mut [u8], level: i32) -> Result<usize>

Compresses a single block of data to the given destination buffer.

Returns the number of bytes written, or an error if something happened (for instance if the destination buffer was too small).

A level of 0 uses zstd's default (currently 3).