Function decode_all
fn decode_all<R: io::Read>(source: R) -> Result<Vec<u8>>
Decompress from the given source as if using a Decoder.
The input data must be in the zstd frame format.
decode_allfn decode_all<R: io::Read>(source: R) -> Result<Vec<u8>>
Decompress from the given source as if using a Decoder.
The input data must be in the zstd frame format.