Function decompress_to_buffer
fn decompress_to_buffer(source: &[u8], destination: &mut [u8]) -> Result<usize>
Deompress a single block of data to the given destination buffer.
Returns the number of bytes written, or an error if something happened (for instance if the destination buffer was too small).