Struct EncoderDictionary
struct EncoderDictionary<'a> { ... }
Prepared dictionary for compression
A dictionary can include its own copy of the data (if it is 'static), or it can merely point
to a separate buffer (if it has another lifetime).
Implementations
impl EncoderDictionary<'static>
fn copy(dictionary: &[u8], level: i32) -> SelfCreates a prepared dictionary for compression.
This will copy the dictionary internally.
impl<'a> EncoderDictionary<'a>
fn as_cdict(self: &Self) -> &CDict<'a>Returns reference to
CDictinner object
impl<'a> Freeze for EncoderDictionary<'a>
impl<'a> RefUnwindSafe for EncoderDictionary<'a>
impl<'a> Send for EncoderDictionary<'a>
impl<'a> Sync for EncoderDictionary<'a>
impl<'a> Unpin for EncoderDictionary<'a>
impl<'a> UnsafeUnpin for EncoderDictionary<'a>
impl<'a> UnwindSafe for EncoderDictionary<'a>
impl<T> Any for EncoderDictionary<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for EncoderDictionary<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for EncoderDictionary<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for EncoderDictionary<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for EncoderDictionary<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for EncoderDictionary<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for EncoderDictionary<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>